import { Construct } from "constructs";
interface InstallerOptionsBase {
    /**
     * The ec2 instance id to install the ssm document on
     */
    readonly instanceId: string;
    /**
     * The name of the custom ssm document to install.
     *
     * @default the ssm document of the construct
     */
    readonly documentName?: string;
    /**
     * The name of the cloudwatch log group for the install logs
     *
     * @default /aws/ssm/${documentName}
     */
    readonly cloudWatchLogGroupName?: string;
    /**
     * The name of the user under which the vscode server runs
     */
    readonly vsCodeUser: string;
    /**
     * The password of the user under which the vscode server runs
     */
    readonly vsCodePassword: string;
    /**
     * The home folder of the user under which the vscode server runs
     */
    readonly homeFolder: string;
    /**
     * The base rest path vs code server will run
     *
     * @default app
     */
    readonly devServerBasePath?: string;
    /**
     * The port vscoder server will be served in the instance
     *
     * @default 8081
     */
    readonly devServerPort?: number;
}
export interface InstallerOptions extends InstallerOptionsBase {
}
export declare abstract class Installer {
    static ubuntu(options: InstallerOptions): Installer;
    static amazonLinux2023(options: InstallerOptions): Installer;
    instanceId: string;
    documentName: string;
    cloudWatchLogGroupName: string;
    vsCodePassword: string;
    vsCodePasswordTest: string;
    /**
     * @internal
     */
    protected constructor();
    /**
     * @internal
     */
    abstract _bind(scope: Construct): any;
    private createSSMDocument;
}
export {};
